@@ -27,6 +27,33 @@ JUSTIFICATION = 'justification'
 REINSTALL = 'reinstall'
 SIGNATURE_TYPE = 'signature_type'
 
+REVOC_TYPE = "revocDefType"
+ID = "id"
+TAG = "tag"
+CRED_DEF_ID = "credDefId"
+ISSUANCE_TYPE = "issuanceType"
+MAX_CRED_NUM = "maxCredNum"
+PUBLIC_KEYS = "publicKeys"
+TAILS_HASH = "tailsHash"
+TAILS_LOCATION = "tailsLocation"
+SUBMITTER_DID = "submitterDid"
+VALUE = "value"
+REQ_METADATA = "reqMetadata"
+REVOC_REG_DEF_ID = "revocRegDefId"
+PREV_ACCUM = "prevAccum"
+ACCUM = "accum"
+ACCUM_FROM = "accum_from"
+ACCUM_TO = "accum_to"
+ISSUED = "issued"
+REVOKED = "revoked"
+ISSUANCE_BY_DEFAULT = "ISSUANCE_BY_DEFAULT"
+ISSUANCE_ON_DEMAND = "ISSUANCE_ON_DEMAND"
+TIMESTAMP = 'timestamp'
+FROM = "from"
+TO = "to"
+STATE_PROOF_FROM = "stateProofFrom"
+REVOC_REG_ID = "revocRegId"
+
 NULL = 'null'
 OWNER = '<owner>'
 
@@ -83,12 +110,17 @@ NYM = IndyTransactions.NYM.value
 ATTRIB = IndyTransactions.ATTRIB.value
 SCHEMA = IndyTransactions.SCHEMA.value
 CLAIM_DEF = IndyTransactions.CLAIM_DEF.value
+REVOC_REG_DEF = IndyTransactions.REVOC_REG_DEF.value
+REVOC_REG_ENTRY = IndyTransactions.REVOC_REG_ENTRY.value
 DISCLO = IndyTransactions.DISCLO.value
 GET_ATTR = IndyTransactions.GET_ATTR.value
 GET_NYM = IndyTransactions.GET_NYM.value
 GET_TXNS = IndyTransactions.GET_TXNS.value
 GET_SCHEMA = IndyTransactions.GET_SCHEMA.value
 GET_CLAIM_DEF = IndyTransactions.GET_CLAIM_DEF.value
+GET_REVOC_REG_DEF = IndyTransactions.GET_REVOC_REG_DEF.value
+GET_REVOC_REG = IndyTransactions.GET_REVOC_REG.value
+GET_REVOC_REG_DELTA = IndyTransactions.GET_REVOC_REG_DELTA.value
 
 POOL_UPGRADE = IndyTransactions.POOL_UPGRADE.value
 NODE_UPGRADE = IndyTransactions.NODE_UPGRADE.value
@@ -101,7 +133,9 @@ fields = {NYM: ([TARGET_NYM], [ROLE]),
           SCHEMA: ([NAME, VERSION, ATTR_NAMES]),
           GET_SCHEMA: ([], []),
           CLAIM_DEF: ([REF, DATA, SIGNATURE_TYPE]),
-          GET_CLAIM_DEF: ([REF, ORIGIN, SIGNATURE_TYPE])
+          GET_CLAIM_DEF: ([REF, ORIGIN, SIGNATURE_TYPE]),
+          REVOC_REG_DEF: ([ID, TYPE, TAG, CRED_DEF_ID, VALUE]),
+          REVOC_REG_ENTRY: ([REVOC_REG_DEF_ID, TYPE, VALUE]),
           }
 
 CONFIG_TXN_TYPES = {POOL_UPGRADE, NODE_UPGRADE, POOL_CONFIG}
