@@ -2,10 +2,8 @@ import json
 from copy import deepcopy
 from hashlib import sha256
 
-from plenum.common.constants import TARGET_NYM, NONCE, RAW, ENC, HASH, NAME, VERSION, ORIGIN, FORCE
-from plenum.common.messages.fields import IterableField, AnyMapField, \
-    NonEmptyStringField, LedgerIdField as PLedgerIdField, \
-    LedgerInfoField as PLedgerInfoField
+from plenum.common.constants import TARGET_NYM, NONCE, RAW, ENC, HASH, NAME, \
+    VERSION, ORIGIN, FORCE
 from plenum.common.messages.node_message_factory import node_message_factory
 
 from plenum.common.messages.message_base import MessageValidator
@@ -13,7 +11,8 @@ from plenum.common.request import Request as PRequest
 from plenum.common.types import OPERATION
 from plenum.common.messages.node_messages import NonNegativeNumberField
 from plenum.common.messages.fields import ConstantField, IdentifierField, LimitedLengthStringField, TxnSeqNoField, \
-    Sha256HexField, JsonField, MapField, BooleanField, VersionField, ChooseField
+    Sha256HexField, JsonField, MapField, BooleanField, VersionField, ChooseField, IntegerField, IterableField, \
+    AnyMapField, NonEmptyStringField
 from plenum.common.messages.client_request import ClientOperationField as PClientOperationField
 from plenum.common.messages.client_request import ClientMessageValidator as PClientMessageValidator
 from plenum.common.util import is_network_ip_address_valid, is_network_port_valid
@@ -26,7 +25,12 @@ from indy_common.constants import TXN_TYPE, allOpKeys, ATTRIB, GET_ATTR, \
     DATA, GET_NYM, reqOpKeys, GET_TXNS, GET_SCHEMA, GET_CLAIM_DEF, ACTION, \
     NODE_UPGRADE, COMPLETE, FAIL, CONFIG_LEDGER_ID, POOL_UPGRADE, POOL_CONFIG, \
     DISCLO, ATTR_NAMES, REVOCATION, SCHEMA, ENDPOINT, CLAIM_DEF, REF, SIGNATURE_TYPE, SCHEDULE, SHA256, \
-    TIMEOUT, JUSTIFICATION, JUSTIFICATION_MAX_SIZE, REINSTALL, WRITES, PRIMARY, START, CANCEL
+    TIMEOUT, JUSTIFICATION, JUSTIFICATION_MAX_SIZE, REINSTALL, WRITES, PRIMARY, START, CANCEL, \
+    REVOC_REG_DEF, ISSUANCE_TYPE, MAX_CRED_NUM, PUBLIC_KEYS, \
+    TAILS_HASH, TAILS_LOCATION, ID, REVOC_TYPE, TAG, CRED_DEF_ID, VALUE, \
+    REVOC_REG_ENTRY, ISSUED, REVOC_REG_DEF_ID, REVOKED, ACCUM, PREV_ACCUM, \
+    GET_REVOC_REG_DEF, GET_REVOC_REG, TIMESTAMP, \
+    GET_REVOC_REG_DELTA, FROM, TO
 
 
 class Request(PRequest):
@@ -73,7 +77,9 @@ class SchemaField(MessageValidator):
     schema = (
         (NAME, LimitedLengthStringField(max_length=NAME_FIELD_LIMIT)),
         (VERSION, VersionField(components_number=(2, 3,), max_length=VERSION_FIELD_LIMIT)),
-        (ATTR_NAMES, IterableField(LimitedLengthStringField(max_length=NAME_FIELD_LIMIT))),
+        (ATTR_NAMES, IterableField(
+            LimitedLengthStringField(max_length=NAME_FIELD_LIMIT),
+            min_length=1)),
     )
 
 
@@ -84,6 +90,45 @@ class ClaimDefField(MessageValidator):
     )
 
 
+class RevocDefValueField(MessageValidator):
+    schema = (
+        (ISSUANCE_TYPE, NonEmptyStringField()),
+        (MAX_CRED_NUM, IntegerField()),
+        (PUBLIC_KEYS, AnyMapField()),
+        (TAILS_HASH, NonEmptyStringField()),
+        (TAILS_LOCATION, NonEmptyStringField()),
+    )
+
+
+class ClientRevocDefSubmitField(MessageValidator):
+    schema = (
+        (TXN_TYPE, ConstantField(REVOC_REG_DEF)),
+        (ID, NonEmptyStringField()),
+        (REVOC_TYPE, NonEmptyStringField()),
+        (TAG, NonEmptyStringField()),
+        (CRED_DEF_ID, NonEmptyStringField()),
+        (VALUE, RevocDefValueField())
+    )
+
+
+class RevocRegEntryValueField(MessageValidator):
+    schema = (
+        (PREV_ACCUM, NonEmptyStringField(optional=True)),
+        (ACCUM, NonEmptyStringField()),
+        (ISSUED, IterableField(inner_field_type=IntegerField(), optional=True)),
+        (REVOKED, IterableField(inner_field_type=IntegerField(), optional=True))
+    )
+
+
+class ClientRevocRegEntrySubmitField(MessageValidator):
+    schema = (
+        (TXN_TYPE, ConstantField(REVOC_REG_ENTRY)),
+        (REVOC_REG_DEF_ID, NonEmptyStringField()),
+        (REVOC_TYPE, NonEmptyStringField()),
+        (VALUE, RevocRegEntryValueField())
+    )
+
+
 class ClientSchemaOperation(MessageValidator):
     schema = (
         (TXN_TYPE, ConstantField(SCHEMA)),
@@ -105,15 +150,15 @@ class ClientAttribOperation(MessageValidator):
         (TARGET_NYM, IdentifierField(optional=True)),
         (RAW, JsonField(max_length=JSON_FIELD_LIMIT, optional=True)),
         (ENC, LimitedLengthStringField(max_length=ENC_FIELD_LIMIT, optional=True)),
-        (HASH, LimitedLengthStringField(max_length=HASH_FIELD_LIMIT, optional=True)),
+        (HASH, Sha256HexField(optional=True)),
     )
 
     def _validate_message(self, msg):
-        self.__validate_field_set(msg)
+        self._validate_field_set(msg)
         if RAW in msg:
             self.__validate_raw_field(msg[RAW])
 
-    def __validate_field_set(self, msg):
+    def _validate_field_set(self, msg):
         fields_n = sum(1 for f in (RAW, ENC, HASH) if f in msg)
         if fields_n == 0:
             self._raise_missed_fields(RAW, ENC, HASH)
@@ -157,13 +202,18 @@ class ClientAttribOperation(MessageValidator):
                                        'invalid endpoint port')
 
 
-class ClientGetAttribOperation(MessageValidator):
+class ClientGetAttribOperation(ClientAttribOperation):
     schema = (
         (TXN_TYPE, ConstantField(GET_ATTR)),
         (TARGET_NYM, IdentifierField(optional=True)),
-        (RAW, LimitedLengthStringField(max_length=RAW_FIELD_LIMIT)),
+        (RAW, LimitedLengthStringField(max_length=RAW_FIELD_LIMIT, optional=True)),
+        (ENC, LimitedLengthStringField(max_length=ENC_FIELD_LIMIT, optional=True)),
+        (HASH, Sha256HexField(optional=True)),
     )
 
+    def _validate_message(self, msg):
+        self._validate_field_set(msg)
+
 
 class ClientClaimDefSubmitOperation(MessageValidator):
     schema = (
@@ -183,6 +233,30 @@ class ClientClaimDefGetOperation(MessageValidator):
     )
 
 
+class ClientGetRevocRegDefField(MessageValidator):
+    schema = (
+        (ID, NonEmptyStringField()),
+        (TXN_TYPE, ConstantField(GET_REVOC_REG_DEF)),
+    )
+
+
+class ClientGetRevocRegField(MessageValidator):
+    schema = (
+        (REVOC_REG_DEF_ID, NonEmptyStringField()),
+        (TIMESTAMP, IntegerField()),
+        (TXN_TYPE, ConstantField(GET_REVOC_REG)),
+    )
+
+
+class ClientGetRevocRegDeltaField(MessageValidator):
+    schema = (
+        (TXN_TYPE, ConstantField(GET_REVOC_REG_DELTA)),
+        (REVOC_REG_DEF_ID, NonEmptyStringField()),
+        (FROM, IntegerField(optional=True)),
+        (TO, IntegerField()),
+    )
+
+
 class ClientPoolUpgradeOperation(MessageValidator):
     schema = (
         (TXN_TYPE, ConstantField(POOL_UPGRADE)),
@@ -221,6 +295,11 @@ class ClientOperationField(PClientOperationField):
         GET_SCHEMA: ClientGetSchemaOperation(),
         POOL_UPGRADE: ClientPoolUpgradeOperation(),
         POOL_CONFIG: ClientPoolConfigOperation(),
+        REVOC_REG_DEF: ClientRevocDefSubmitField(),
+        REVOC_REG_ENTRY: ClientRevocRegEntrySubmitField(),
+        GET_REVOC_REG_DEF: ClientGetRevocRegDefField(),
+        GET_REVOC_REG: ClientGetRevocRegField(),
+        GET_REVOC_REG_DELTA: ClientGetRevocRegDeltaField(),
     }
 
     # TODO: it is a workaround because INDY-338, `operations` must be a class
@@ -239,21 +318,22 @@ class ClientMessageValidator(PClientMessageValidator):
     )
 
 
-class LedgerIdField(PLedgerIdField):
-    ledger_ids = PLedgerIdField.ledger_ids + (CONFIG_LEDGER_ID,)
-
-
-class LedgerInfoField(PLedgerInfoField):
-    _ledger_id_class = LedgerIdField
+# THE CODE BELOW MIGHT BE NEEDED IN THE FUTURE, THEREFORE KEEPING IT
+# class LedgerIdField(PLedgerIdField):
+#     ledger_ids = PLedgerIdField.ledger_ids + (CONFIG_LEDGER_ID,)
+#
+#
+# class LedgerInfoField(PLedgerInfoField):
+#     _ledger_id_class = LedgerIdField
 
 
 # TODO: it is a workaround which helps extend some fields from
 # downstream projects, should be removed after we find a better way
 # to do this
-node_message_factory.update_schemas_by_field_type(
-    PLedgerIdField, LedgerIdField)
-node_message_factory.update_schemas_by_field_type(
-    PLedgerInfoField, LedgerInfoField)
+# node_message_factory.update_schemas_by_field_type(
+#     PLedgerIdField, LedgerIdField)
+# node_message_factory.update_schemas_by_field_type(
+#     PLedgerInfoField, LedgerInfoField)
 
 
 class SafeRequest(Request, ClientMessageValidator):
