@@ -14,19 +14,13 @@ def test_nym_send_twice(looper, sdk_pool_handle, sdk_wallet_steward):
     for i in range(2):
         request = looper.loop.run_until_complete(build_nym_request(identifier, idr, verkey, None, None))
         req_signed = looper.loop.run_until_complete(sign_request(wallet_handle, identifier, request))
+        result = json.loads(looper.loop.run_until_complete(submit_request(sdk_pool_handle, req_signed)))
 
         if i == 0:
-            result = json.loads(looper.loop.run_until_complete(submit_request(sdk_pool_handle, req_signed)))
             assert result['op'] == REPLY
         else:
-            # TODO(INDY-1069): Ugly hack to deal with old libindy which raises exception on REJECT,
-            # in fact it should be simple:
-            # assert result['op'] == REJECT
-            try:
-                json.loads(looper.loop.run_until_complete(submit_request(sdk_pool_handle, req_signed)))
-                assert False
-            except IndyError as ex:
-                assert ex.error_code == ErrorCode.LedgerInvalidTransaction
+            assert result['op'] == REJECT
+
 
 def test_nym_resend(looper, sdk_pool_handle, sdk_wallet_steward):
     idr, verkey = createHalfKeyIdentifierAndAbbrevVerkey()
@@ -38,4 +32,4 @@ def test_nym_resend(looper, sdk_pool_handle, sdk_wallet_steward):
 
     for i in range(2):
         result = json.loads(looper.loop.run_until_complete(submit_request(sdk_pool_handle, req_signed)))
-        assert result['op'] == REPLY
\ No newline at end of file
+        assert result['op'] == REPLY
