@@ -116,10 +116,15 @@ class NodeControlToolExecutor:
         self.p.terminate()
         # check that process with NodeControlTool.start function really stop.
         # process.terminate() just send SIGTERM and is not guarantee that process stops
-        while self.p.is_alive():
+        if self.p.is_alive():
             logger.debug("NCTProcess still alive, with pid: {}".format(self.p.pid))
             # while process is still alive, join with main process and wait
-            self.p.join(3)
+
+            # FIXME: here was self.p.join(3), but since we've added (ok, Andrew Nikitin
+            # has added) handler for SIGTERM here we wait for child process infinitely,
+            # but for now we have no time to fix it in more elegant way as it is not a
+            # real situation (Andrew said), so he has proposed this ugly hack.
+            os.kill(self.p.pid, 9)
         logger.debug("NCTProcess must be stopped, with pid: {}".format(self.p.pid))
 
 
